@@ -18,8 +18,6 @@ from pyqgisserver.qgscache.cachemanager import (get_cacheservice, get_project_su
  
 from .handler import RequestHandler, register_handlers
 
-from qgis.core import Qgis
-
 LOGGER = logging.getLogger('SRVLOG')
 
 
@@ -49,11 +47,9 @@ class CacheCollection(RequestHandler):
 def register( serverIface ):
     """ Register plugins api handlers
     """
-    # XXX See https://github.com/qgis/QGIS/issues/45439
-    prefix = '/cache' if Qgis.QGIS_VERSION_INT < 32200 else ''
     register_handlers(serverIface, "/cache","CacheManagment",
                       [
-                          (rf'{prefix}/(?P<key>.+)$', CacheCollection),
+                          (r'/(?P<key>.+)$', CacheCollection),
                           (r'/', CacheCollection),
                       ])
                       
